"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FrameSlider = void 0;
var React = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _Frame = _interopRequireDefault(require("./Frame"));
var _Marker = _interopRequireDefault(require("./Marker"));
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
const itemAmountPerScreen = 10;
class FrameSlider extends React.Component {
  constructor(props) {
    super(props);
    _defineProperty(this, "flatList", /*#__PURE__*/React.createRef());
    _defineProperty(this, "onLayout", event => {
      this.setState({
        width: event.nativeEvent.layout.width,
        oneItemWidth: Math.round(event.nativeEvent.layout.width / itemAmountPerScreen)
      });
      this.init();
    });
    _defineProperty(this, "onSliderMoved", event => {
      const {
        oneItemWidth
      } = this.state;
      const {
        onValueChange,
        initialPositionValue,
        maximumValue,
        decimalPlaces
      } = this.props;
      let newValue = initialPositionValue + event.nativeEvent.contentOffset.x / oneItemWidth * this.props.multiplicity;
      if (maximumValue && newValue > maximumValue) {
        newValue = maximumValue;
      }
      const setValue = parseFloat(parseFloat(newValue.toString()).toFixed(decimalPlaces));
      this.setState({
        value: setValue
      });
      onValueChange(setValue);
    });
    _defineProperty(this, "generateArrayBlock", () => {
      const {
        arrayLength,
        maximumValue,
        multiplicity
      } = this.props;
      let length = arrayLength;
      if (maximumValue) {
        length = maximumValue / multiplicity;
        length += itemAmountPerScreen;
      }
      return new Array(length).fill(0);
    });
    _defineProperty(this, "init", () => {
      setTimeout(() => this.scrollToElement(this.props.value), 100);
    });
    _defineProperty(this, "scrollToElement", value => this.flatList.current && this.flatList.current.scrollToOffset({
      offset: value * this.state.oneItemWidth / this.props.multiplicity,
      animated: false
    }));
    _defineProperty(this, "renderFrame", element => /*#__PURE__*/React.createElement(_Frame.default, {
      duration: this.props.duration,
      index: element.index,
      framesPath: this.props.framesPath
    }));
    _defineProperty(this, "renderDefaultThumb", () => /*#__PURE__*/React.createElement(_Marker.default, {
      thumbStyle: this.props.thumbStyle
    }));
    this.state = {
      items: this.generateArrayBlock(),
      width: 0,
      oneItemWidth: 0,
      value: props.initialPositionValue
    };
  }
  shouldComponentUpdate(nextProps, nextState) {
    const {
      width
    } = this.state;
    if (width === 0 && nextState.width !== 0) {
      return true;
    }
    if (nextProps.value !== nextState.value) {
      this.setState({
        value: nextProps.value
      });
      this.scrollToElement(nextProps.value);
    }
    return false;
  }
  render() {
    const {
      renderThumb,
      scrollEnabled,
      mainContainerStyle
    } = this.props;
    const {
      items,
      width
    } = this.state;
    return /*#__PURE__*/React.createElement(_reactNative.View, {
      style: [_styles.default.mainContainer, mainContainerStyle],
      onLayout: this.onLayout
    }, /*#__PURE__*/React.createElement(_reactNative.FlatList, {
      style: [_styles.default.flatlistContainer, this.props.flatlistStyle && this.props.flatlistStyle],
      ref: this.flatList,
      getItemLayout: (_, index) => ({
        length: this.state.oneItemWidth,
        offset: this.state.oneItemWidth * index,
        index
      }),
      scrollEnabled: scrollEnabled,
      data: width === 0 ? [] : items,
      keyboardShouldPersistTaps: 'always',
      horizontal: true,
      onScrollEndDrag: this.onSliderMoved,
      onScroll: this.onSliderMoved,
      onMomentumScrollBegin: this.onSliderMoved,
      onMomentumScrollEnd: this.onSliderMoved,
      keyExtractor: (_, index) => index.toString(),
      renderItem: this.renderFrame,
      showsHorizontalScrollIndicator: false
    }), renderThumb ? renderThumb() : this.renderDefaultThumb());
  }
}
exports.FrameSlider = FrameSlider;
_defineProperty(FrameSlider, "defaultProps", {
  multiplicity: 0.1,
  decimalPlaces: 1,
  arrayLength: 10000,
  scrollEnabled: true,
  mainContainerStyle: null,
  itemStyle: null,
  tenthItemStyle: null,
  initialPositionValue: 0
});
//# sourceMappingURL=FrameSlider.js.map