"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.VideoManager = void 0;
var _ffmpegKitReactNative = require("ffmpeg-kit-react-native");
var _reactNative = require("react-native");
class VideoManager {
  static async getVideoInfo(path) {
    const command = `-i ${path} -v quiet -print_format json -show_format -show_streams`;
    const response = await _ffmpegKitReactNative.FFprobeKit.execute(command);
    const output = await JSON.parse(await response.getOutput());
    const videoInfo = {
      duration: +output.format.duration,
      creationDate: output.format.tags.creation_time,
      size: +output.format.size,
      bit_rate: +output.format.bit_rate,
      width: +output.streams[1].width,
      height: +output.streams[1].height,
      frame_rate: output.streams[1].avg_frame_rate,
      codec_name: output.streams[1].codec_name,
      codec_type: output.streams[1].codec_type,
      sample_aspect_ratio: output.streams[1].sample_aspect_ratio
    };
    return videoInfo;
  }
  static formatPath(path) {
    const secondDotIndex = path.lastIndexOf('.');
    const newPath = _reactNative.Platform.select({
      ios: path.split('.')[0],
      android: path.substring(0, secondDotIndex)
    });
    return newPath;
  }
  static async createThumbnail(path) {
    let fps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
    const newPath = this.formatPath(path);
    const command = `-i ${path} -vf fps=${fps} ${newPath}_thumb_%01d.jpg`;
    await _ffmpegKitReactNative.FFmpegKit.execute(command);
    const thumnailPath = `${newPath}_thumb_1.jpg`;
    return thumnailPath;
  }
  static async trimVideo(path, startTime, duration) {
    const newPath = this.formatPath(path);
    const outputPath = `${newPath}_trim.mp4`;
    const command = `-y -i ${path} -ss ${startTime} -t ${duration} ${outputPath}`;
    await _ffmpegKitReactNative.FFmpegKit.execute(command);
    return outputPath;
  }
  static async createFrames(path) {
    let fps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
    const newPath = this.formatPath(path);
    const command = `-i ${path} -vf fps=${fps} ${newPath}_thumb_%01d.jpg`;
    await _ffmpegKitReactNative.FFmpegKit.execute(command);
    return `${newPath}_thumb_`;
  }
  static async reverseVideo(path) {
    const newPath = this.formatPath(path);
    const outputPath = `${newPath}_reverse.mp4`;
    const command = `-i ${path} -vf reverse ${outputPath}`;
    await _ffmpegKitReactNative.FFmpegKit.execute(command);
    return outputPath;
  }
  static async mergeVideos(paths, newVideoPath) {
    let height = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '1920';
    let width = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '1080';
    const inputStrings = paths.map(videoPath => `-i ${videoPath}`).join(' ');
    const resizeString = paths.map((_, index) => `[${index}:v]scale=${height}:${width},setsar=1[v${index}]; `).join(' ');
    const concatString = paths.map((_, index) => `[v${index}][${index}:a]`).join('');
    await _ffmpegKitReactNative.FFmpegKit.execute(`-y ${inputStrings}  -filter_complex \
      "${resizeString} \
      ${concatString}concat=n=${paths.length}:v=1:a=1[v][a]" -vsync 2 -map "[v]" -map "[a]" ${newVideoPath}`);
    return newVideoPath;
  }
  static async boomerang(path, reorder) {
    const newPath = this.formatPath(path);
    const reversedVideo = await this.reverseVideo(path);
    const outputPath = `${newPath}_boomerang.mp4`;
    const pathList = reorder ? [reversedVideo, path] : [path, reversedVideo];
    await this.mergeVideos(pathList, `${outputPath}`);
    return outputPath;
  }
  static async setSpeed(path) {
    let speed = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
    const newPath = this.formatPath(path);
    const outputPath = `${newPath}_slow.mp4`;
    const command = `-i ${path} -filter:v "setpts=${1 / speed}*PTS" ${outputPath}`;
    await _ffmpegKitReactNative.FFmpegKit.execute(command);
    return outputPath;
  }
}
exports.VideoManager = VideoManager;
var _default = VideoManager;
exports.default = _default;
//# sourceMappingURL=VideoFunctions.js.map