function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import * as React from 'react';
import { FlatList, View } from 'react-native';
import Frame from './Frame';
import Marker from './Marker';
import styles from './styles';
const itemAmountPerScreen = 10;
export class FrameSlider extends React.Component {
  constructor(props) {
    super(props);
    _defineProperty(this, "flatList", /*#__PURE__*/React.createRef());
    _defineProperty(this, "onLayout", event => {
      this.setState({
        width: event.nativeEvent.layout.width,
        oneItemWidth: Math.round(event.nativeEvent.layout.width / itemAmountPerScreen)
      });
      this.init();
    });
    _defineProperty(this, "onSliderMoved", event => {
      const {
        oneItemWidth
      } = this.state;
      const {
        onValueChange,
        initialPositionValue,
        maximumValue,
        decimalPlaces
      } = this.props;
      let newValue = initialPositionValue + event.nativeEvent.contentOffset.x / oneItemWidth * this.props.multiplicity;
      if (maximumValue && newValue > maximumValue) {
        newValue = maximumValue;
      }
      const setValue = parseFloat(parseFloat(newValue.toString()).toFixed(decimalPlaces));
      this.setState({
        value: setValue
      });
      onValueChange(setValue);
    });
    _defineProperty(this, "generateArrayBlock", () => {
      const {
        arrayLength,
        maximumValue,
        multiplicity
      } = this.props;
      let length = arrayLength;
      if (maximumValue) {
        length = maximumValue / multiplicity;
        length += itemAmountPerScreen;
      }
      return new Array(length).fill(0);
    });
    _defineProperty(this, "init", () => {
      setTimeout(() => this.scrollToElement(this.props.value), 100);
    });
    _defineProperty(this, "scrollToElement", value => this.flatList.current && this.flatList.current.scrollToOffset({
      offset: value * this.state.oneItemWidth / this.props.multiplicity,
      animated: false
    }));
    _defineProperty(this, "renderFrame", element => /*#__PURE__*/React.createElement(Frame, {
      duration: this.props.duration,
      index: element.index,
      framesPath: this.props.framesPath
    }));
    _defineProperty(this, "renderDefaultThumb", () => /*#__PURE__*/React.createElement(Marker, {
      thumbStyle: this.props.thumbStyle
    }));
    this.state = {
      items: this.generateArrayBlock(),
      width: 0,
      oneItemWidth: 0,
      value: props.initialPositionValue
    };
  }
  shouldComponentUpdate(nextProps, nextState) {
    const {
      width
    } = this.state;
    if (width === 0 && nextState.width !== 0) {
      return true;
    }
    if (nextProps.value !== nextState.value) {
      this.setState({
        value: nextProps.value
      });
      this.scrollToElement(nextProps.value);
    }
    return false;
  }
  render() {
    const {
      renderThumb,
      scrollEnabled,
      mainContainerStyle
    } = this.props;
    const {
      items,
      width
    } = this.state;
    return /*#__PURE__*/React.createElement(View, {
      style: [styles.mainContainer, mainContainerStyle],
      onLayout: this.onLayout
    }, /*#__PURE__*/React.createElement(FlatList, {
      style: [styles.flatlistContainer, this.props.flatlistStyle && this.props.flatlistStyle],
      ref: this.flatList,
      getItemLayout: (_, index) => ({
        length: this.state.oneItemWidth,
        offset: this.state.oneItemWidth * index,
        index
      }),
      scrollEnabled: scrollEnabled,
      data: width === 0 ? [] : items,
      keyboardShouldPersistTaps: 'always',
      horizontal: true,
      onScrollEndDrag: this.onSliderMoved,
      onScroll: this.onSliderMoved,
      onMomentumScrollBegin: this.onSliderMoved,
      onMomentumScrollEnd: this.onSliderMoved,
      keyExtractor: (_, index) => index.toString(),
      renderItem: this.renderFrame,
      showsHorizontalScrollIndicator: false
    }), renderThumb ? renderThumb() : this.renderDefaultThumb());
  }
}
_defineProperty(FrameSlider, "defaultProps", {
  multiplicity: 0.1,
  decimalPlaces: 1,
  arrayLength: 10000,
  scrollEnabled: true,
  mainContainerStyle: null,
  itemStyle: null,
  tenthItemStyle: null,
  initialPositionValue: 0
});
//# sourceMappingURL=FrameSlider.js.map